==> IwPopupManager-0.3.1.tar.gz: lang/ext/nl_NL.php <==
<?php
 $lang['friendlyname'] = 'Popup Manager';
 $lang['admindescription'] = 'Een module om popups te beheren';
 
 $lang['yes'] = 'Ja';
 $lang['no'] = 'Nee';
 
 $lang['add_popup'] = 'Nieuwe Popup';
 $lang['edit'] = 'Wijzig';
 $lang['syntax'] = 'Syntax';
 
 $lang['popup_saved'] = 'De popup is nu opgeslagen';
 $lang['submit'] = 'Opslaan';
 $lang['cancel'] = 'Cancel';
 $lang['name'] = 'Naam';
 $lang['content'] = 'Inhoud';
 $lang['active'] = 'Actief';
 $lang['description'] = 'Omschrijving';
 
 $lang['delete'] = 'Verwijder deze';
 $lang['confirm_delete'] = 'Weet u zeker dat u deze popup wilt verwijderen?';
 $lang['popup_deleted'] = 'Deze popup is nu verwijderd';
 $lang['close'] = 'Sluiten';
 $lang['hideafter'] = 'Verberg na';
 $lang['hidefor'] = 'Na 1x tonen verbergen voor gebruiker voor';
 $lang['seconds'] = 'seconden';
 $lang['hours'] = 'uren';
 $lang['pause_description'] = '(0 = verbergt niet automatisch)';
 $lang['duration_description'] = '(0 = altijd tonen)';
 $lang['set_by_cookie'] = '(wordt gecontroleerd via cookie)';
 $lang['disabled'] = 'Uitgeschakeld';
 $lang['timer'] = 'Tijdsduur';
 
 $lang['help'] = <<<EOF
<h3>Hoe Popup Manager te gebruiken.</h3>
<p>Popup Manager laat je op een eenvoudige wijze popups maken en deze vervolgens op je website beschikbaar maken.</p>
<p>De naam van de module is IwPopupManager en het is de eerste module die ik voor CMS Made Simple gemaakt heb.</br>
<br/>
De module zal later nog worden uitgebreid met een aantal extra functies zoals:<br/>
<ul>
<li>Startdate : Vanaf welke datum wordt de popup getoond.</li>
<li>Enddata : Tot welke datum wordt de popup getoond.</li>
<li>Style : Hoe verschijnt en verdwijnt de popup / Transistion style.</li>
<li>Colors : Stel de kleuren van de omlijning, de achtergrond en de tekst in.</li>
<li>Position : Waar wordt de popup getoont (links, rechts, bovenaan, center, onderaan)</li>
</ul>
<br>
<p>Om een popup aan te maken open je de Popup Manager te vinden onder Inhoud en voegt een nieuwe popup toe. Op de regel van de popup zie je de tag die je volgens dient te gebruiken. 
Voeg deze tag toe aan je template (de popup zal op iedere pagina verschijnen) of voeg hem de pagine waarop de popup getoont moet worden. 
Omdat je meerdere popups kunt aanmaken kan iedere pagina zijn eigen popup hebben indien gewenst. 
Het is niet verstandig om meerdere popups op 1 pagina te plaatsen om dat dit (nog) niet correct werkt.</p>
<br/>
<p>Voorbeeld :<br>
Wanneer je een popup wilt laten verschijnen op de frontpage van je website, plaats dan de tag in de inhoud van de frontpage . bv {cms_module module=IwPopupManager id=2} somewhere on the frontpage content.<br/>
De positie van de tag is niet belangrijk omdat de popup vooralsnog altijd in het midden van het browserscherm verschiijnt.<p/>
<br /><br />
LET OP: Vanaf versie 0.3 maakt deze module gebruik van functionele cookies. Vermeld (ivm AVG en GDPR) op je website dat er functionele cookies worden gebruikt.<br/>
<br />
<p>Zoals gezegd, dit is de eerste keer dat ik een module maak voor CMS Made Simple en er valt nog een hoop te leren.<br/>
Heb je aan/opmerking of heb je ideeen hoe ik een en ander kan verbeteren, dan hoor ik dat graag. 
EOF;
 ?>

==> IwPopupManager-0.4.tar.gz: lang/ext/nl_NL.php <==
<?php
 $lang['friendlyname'] = 'Popup Manager';
 $lang['admindescription'] = 'Een module om popups te beheren';
 
 $lang['yes'] = 'Ja';
 $lang['no'] = 'Nee';
 
 $lang['add_popup'] = 'Nieuwe Popup';
 $lang['edit'] = 'Wijzig';
 $lang['syntax'] = 'Syntax';
 
 $lang['popup_saved'] = 'De popup is nu opgeslagen';
 $lang['submit'] = 'Opslaan';
 $lang['cancel'] = 'Cancel';
 $lang['name'] = 'Naam';
 $lang['content'] = 'Inhoud';
 $lang['active'] = 'Actief';
 $lang['description'] = 'Omschrijving';
 
 $lang['delete'] = 'Verwijder deze';
 $lang['confirm_delete'] = 'Weet u zeker dat u deze popup wilt verwijderen?';
 $lang['popup_deleted'] = 'Deze popup is nu verwijderd';
 $lang['close'] = 'Sluiten';
 $lang['hideafter'] = 'Verberg na';
 $lang['hidefor'] = 'Na 1x tonen verbergen voor gebruiker voor';
 $lang['seconds'] = 'seconden';
 $lang['hours'] = 'uren';
 $lang['pause_description'] = '(0 = verbergt niet automatisch)';
 $lang['duration_description'] = '(0 = altijd tonen)';
 $lang['set_by_cookie'] = '(wordt gecontroleerd via cookie)';
 $lang['disabled'] = 'Uitgeschakeld';
 $lang['timer'] = 'Tijdsduur';
 $lang['style'] = 'Stijl';
  $lang['fadein-fadeout'] = 'Fadein / Fadeout';
 $lang['zoomin-zoomout'] = 'Zoom in / Zoom out';
 $lang['top-to-bottom'] = 'Boven naar Onder';
 $lang['bottom-to-top'] = 'Onder naar Boven';
 $lang['left-to-right'] = 'Links naar rechts';
 $lang['right-to-left'] = 'Rechts naar links';
 
 $lang['help'] = <<<EOF
<h3>Hoe Popup Manager te gebruiken.</h3>
<p>Popup Manager laat je op een eenvoudige wijze popups maken en deze vervolgens op je website beschikbaar maken.</p>
<p>De naam van de module is IwPopupManager en het is de eerste module die ik voor CMS Made Simple gemaakt heb.</br>
<br/>
De module zal later nog worden uitgebreid met een aantal extra functies zoals:<br/>
<ul>
<li>Startdate : Vanaf welke datum wordt de popup getoond.</li>
<li>Enddata : Tot welke datum wordt de popup getoond.</li>
<li>Colors : Stel de kleuren van de omlijning, de achtergrond en de tekst in.</li>
<li>Position : Waar wordt de popup getoont (links, rechts, bovenaan, center, onderaan)</li>
</ul>
<br>
<p>Om een popup aan te maken open je de Popup Manager te vinden onder Inhoud en voegt een nieuwe popup toe. Op de regel van de popup zie je de tag die je volgens dient te gebruiken. 
Voeg deze tag toe aan je template (de popup zal op iedere pagina verschijnen) of voeg hem de pagine waarop de popup getoont moet worden. 
Omdat je meerdere popups kunt aanmaken kan iedere pagina zijn eigen popup hebben indien gewenst. 
Het is niet verstandig om meerdere popups op 1 pagina te plaatsen om dat dit (nog) niet correct werkt.</p>
<br/>
<p>Voorbeeld :<br>
Wanneer je een popup wilt laten verschijnen op de frontpage van je website, plaats dan de tag in de inhoud van de frontpage . bv {cms_module module=IwPopupManager id=2} somewhere on the frontpage content.<br/>
De positie van de tag is niet belangrijk omdat de popup vooralsnog altijd in het midden van het browserscherm verschiijnt.<p/>
<br /><br />
LET OP: Vanaf versie 0.3 maakt deze module gebruik van functionele cookies. Vermeld (ivm AVG en GDPR) op je website dat er functionele cookies worden gebruikt.<br/>
<br />
<p>Zoals gezegd, dit is de eerste keer dat ik een module maak voor CMS Made Simple en er valt nog een hoop te leren.<br/>
Heb je aan/opmerking of heb je ideeen hoe ik een en ander kan verbeteren, dan hoor ik dat graag. 
EOF;
 ?>
